/*
 * Copyright 2011 Waki Takeya
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jp.develop.gae.command;

/**
 * Command result class.
 * @author Waki Takeya
 */
public class Result {

	public static final int SUCCESS = 0;
	public static final int FATAL_AUTHENTICATION = 1;	// Retry after login.
	public static final int ERROR_OPTIMISTIC_LOCK = 2;	// Retry later.
	public static final int FATAL_OPTIMISTIC_LOCK = 3;	// Retry with new revision. (or already updated)
	public static final int FATAL_INTERNAL = 99;
	public static final int ERROR_APPLICATION = 100;	// or Above.

	private Object data;
	private int code;
	private String message;

	/**
	 * Construct a instance with specified data, code and message.
	 * @param data command result data.
	 * @param code result code. zero for success.
	 * @param message error message.
	 */
	public Result(Object data, int code, String message) {
		this.data = data;
		this.code = code;
		this.message = message;
	}

	/**
	 * Get command result data.
	 * @return Command result data.
	 */
	public Object getData() {
		return data;
	}
	/**
	 * Get result code.
	 * @return Result code.
	 */
	public int getCode() {
		return code;
	}
	/**
	 * Get error message.
	 * @return Error message.
	 */
	public String getMessage() {
		return message;
	}
}
