/*
 * Copyright 2011 Waki Takeya
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jp.develop.gae.command.sample;

import java.util.List;

import jp.develop.gae.command.ICommand;

/**
 * Sample command, which show bean encoding.
 * @author Waki Takeya
 */
public class BeanTestCommand implements ICommand<String> {

	/** Business data sample. */
	public Header header;

	@Override
	public String execute() {
		return header.toString();
	}

	/**
	 * Sample header bean.
	 * @author Waki Takeya
	 */
	public static class Header {
		private String title;
		private long seq;
		private List<Detail> details;

		@Override
		public String toString() {
			StringBuilder builder = new StringBuilder();
			builder.append("Title: ").append(title).append("\n");
			builder.append("Seq: ").append(seq).append("\n");
			builder.append("Details:").append("\n");
			for (Detail detail : this.details) {
				builder.append("  ").append(detail.toString()).append("\n");
			}
			return builder.toString();
		}

		public String getTitle() {
			return title;
		}
		public void setTitle(String title) {
			this.title = title;
		}
		public long getSeq() {
			return seq;
		}
		public void setSeq(long seq) {
			this.seq = seq;
		}
		public List<Detail> getDetails() {
			return details;
		}
		public void setDetails(List<Detail> details) {
			this.details = details;
		}
	}

	/**
	 * Sample detail bean.
	 * @author Waki Takeya
	 */
	public static class Detail {
		private int number;
		private String item;

		@Override
		public String toString() {
			return String.valueOf(this.number) + ": " + this.item;
		}

		public int getNumber() {
			return number;
		}
		public void setNumber(int number) {
			this.number = number;
		}
		public String getItem() {
			return item;
		}
		public void setItem(String item) {
			this.item = item;
		}
	}
}
